import { __decorate } from "tslib";
import { baseLayerLuminance, neutralPalette, accentPalette, density, controlCornerRadius, strokeWidth, designUnit, bodyFont, typeRampBaseFontSize, typeRampBaseLineHeight, } from '@microsoft/fast-components';
import { customElement, FASTElement, observable, attr, DOM } from '@microsoft/fast-element';
import { defaultBodyFont } from '../../types';
import { paletteFromColor } from '../../utils/utils';
import { EventName } from '../design-system-editor';
import { JSON_SCHEMA, uiSchema } from './json_schema';
import { PreviewFormStyles as styles } from './preview-form.styles';
import { PreviewFormTemplate as template } from './preview-form.template';
let PreviewForm = class PreviewForm extends FASTElement {
    constructor() {
        super(...arguments);
        this.jsonSchema = JSON_SCHEMA;
        this.uischema = uiSchema;
        this.prefix = 'zero';
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                this.applyStyleChanges(detail);
            });
        }
    }
    applyStyleChanges(detail) {
        const neutral = paletteFromColor(detail.neutralColor);
        neutralPalette.setValueFor(this.provider, neutral);
        const accent = paletteFromColor(detail.accentColor);
        accentPalette.setValueFor(this.provider, accent);
        baseLayerLuminance.setValueFor(this.provider, detail.luminance);
        density.setValueFor(this.provider, detail.density);
        controlCornerRadius.setValueFor(this.provider, detail.borderRadius);
        strokeWidth.setValueFor(this.provider, detail.strokeWidth);
        designUnit.setValueFor(this.provider, detail.designUnit);
        bodyFont.setValueFor(this.provider, detail.bodyFont);
        typeRampBaseFontSize.setValueFor(this.provider, detail.baseFontSize);
        typeRampBaseLineHeight.setValueFor(this.provider, detail.baseLineHeight);
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.uischema.dsPrefix = event.detail.prefix;
    }
};
__decorate([
    observable
], PreviewForm.prototype, "jsonSchema", void 0);
__decorate([
    observable
], PreviewForm.prototype, "uischema", void 0);
__decorate([
    attr
], PreviewForm.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewForm.prototype, "provider", void 0);
PreviewForm = __decorate([
    customElement({
        name: 'preview-form',
        template,
        styles,
    })
], PreviewForm);
export { PreviewForm };
